@@ -57,7 +57,7 @@ class StreamApp(object):
                     continue
                 else:
                     return
-            self.actor_running(self.current_actor_state)
+            self.actor_running()
             # msgs消息格式
             # [[b'Source&success', [(b'1652346017746-2', {b'': b'{"payload": "C1(=N/NC(COC2C(Cl)=CC(=CC=2Cl)Cl)=O)\\\\C2C=C(Br)C=C(C)C=2N(C)C\\\\1=O\\tMCULE-8250840838\\n", "flag": "0", "type": "TextOutputPort"}'})]]]
             for msg in msgs:
@@ -145,10 +145,10 @@ class StreamApp(object):
     '''
     更新actor的状态为running
     '''
-    def actor_running(self, parallel_index) -> None:
+    def actor_running(self) -> None:
         if self.current_actor_state == actor_constant.ACTOR_STATE_READY:
             # 调用flow_namager接口修改actor的状态为running
-            self.state_manager.update_actor_state(self.current_actor_name, parallel_index, actor_constant.ACTOR_STATE_RUNNING)
+            self.state_manager.update_actor_state(self.current_actor_name, self.parallel_index, actor_constant.ACTOR_STATE_RUNNING)
             self.current_actor_state = actor_constant.ACTOR_STATE_RUNNING
 
 
@@ -240,7 +240,7 @@ class StreamApp(object):
             module = str(config.PARAM_PATH)
             param_module = importlib.import_module(module)
             param_class = getattr(param_module, param_type)
-            param = param_class(name=param_name, description=param_description, value=param_value)
+            param = param_class(name=param_name, value=param_value)
             setattr(args, param_variable, param_value)
             setattr(args, param_variable+"_object", param)
         return args
