@@ -9,7 +9,7 @@ class Args(object):
 
 class Actor(Generic[T]):
 
-    def __init__(self, name: str, actor_id: str = None):
+    def __init__(self, name: str = None, actor_id: str = None):
         self.__name = name
         self.__id = actor_id
         self.__output_ports = []
